# Reddit Profile Importer

With this importer you can import reddit profiles from specific subreddits and insert them into the database.

## Prerequisits
You will need:
* A reddit account
* A reddit app, in order to get one, use this link : https://www.reddit.com/prefs/apps.
* Here is a video tutorial for creating an app:
    https://www.youtube.com/watch?v=4Lmfgw4RZCM

* once you have the app, you will need to add to the python 2 enviorment variables:
    REDDIT_CLIENT_ID: you can find the value under the app name at  https://www.reddit.com/prefs/apps
    REDDIT_CLIENT_SECRET: also can be found in the app window you created
    REDDIT_USERNAME: your reddit username
